import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { LocalStorageService, StorageKeys } from '@progress-chef/platform-storage-service';
import * as i1 from '@progress-chef/platform-shared-store';

class RefreshTokenService {
    constructor(chefPlatformUserAccountsIdentitySharedFacadeService) {
        this.chefPlatformUserAccountsIdentitySharedFacadeService = chefPlatformUserAccountsIdentitySharedFacadeService;
        this.expiryTime = -1;
        this.baseUrl = '';
        this.isUserActive = false;
        this.refreshInProgress = false;
        this.refreshTokenMissed = false;
        // set token refresh to false if token refresh is not done in 5 seconds
        if (LocalStorageService.getItem(StorageKeys.TOKEN_REFRESH) &&
            LocalStorageService.getItem(StorageKeys.TOKEN_REFRESH).active &&
            LocalStorageService.getItem(StorageKeys.TOKEN_REFRESH).time < new Date().getTime() - 5000) {
            LocalStorageService.setItem(StorageKeys.TOKEN_REFRESH, { "active": false, "time": new Date().getTime() });
        }
        this.refreshJWTTokenSubscription$ = this.chefPlatformUserAccountsIdentitySharedFacadeService.identityGetSelfUser$().subscribe(({ createStatus, details: userDetails }) => {
            LocalStorageService.setItem(StorageKeys.TOKEN_REFRESH, { "active": false, "time": new Date().getTime() });
        });
    }
    refreshToken(reqPayload, setOrgRole = false) {
        const userOrgAndRoleToken = LocalStorageService.getItem(StorageKeys.USER_ORG_AND_ROLE_TOKEN);
        const identityToken = LocalStorageService.getItem(StorageKeys.IDENTITY_TOKEN);
        const refreshToken = userOrgAndRoleToken?.refreshToken || identityToken?.refreshToken;
        if (refreshToken == null) {
            return new Error("refreshToken missing in the localStorage");
        }
        if (setOrgRole) {
            this.chefPlatformUserAccountsIdentitySharedFacadeService.identityRefreshJwt({
                baseUrl: reqPayload?.platformServiceApiBaseUrl,
                reqPayload: { orgId: reqPayload?.organizationId, roleId: reqPayload?.roleId, refreshToken },
                configData: { organizationId: reqPayload?.organizationId, organizationName: reqPayload?.organizationName, roleId: reqPayload?.roleId, roleName: reqPayload?.roleName }
            });
        }
        else if (!LocalStorageService.getItem(StorageKeys.TOKEN_REFRESH)?.active) {
            this.chefPlatformUserAccountsIdentitySharedFacadeService.identityRefreshJwt({
                baseUrl: reqPayload?.platformServiceApiBaseUrl,
                reqPayload: { refreshToken },
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: RefreshTokenService, deps: [{ token: i1.ChefPlatformUserAccountsIdentitySharedFacadeService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: RefreshTokenService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: RefreshTokenService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.ChefPlatformUserAccountsIdentitySharedFacadeService }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RefreshTokenService };
//# sourceMappingURL=progress-chef-platform-refresh-token-service.mjs.map
